Hook

Enum Hook 

pub enum Hook {
    Ingress,
    Prerouting,
    Input,
    Forward,
    Output,
    Postrouting,
}
Representation of nftables chain hooks.

Order of hook execution:

  • Ingress (for netdev-family)
  • Prerouting
  • Input
  • Forward
  • Output
  • Postrouting

Attribution

Parts of the documentation have been taken from https://wiki.nftables.org/wiki-nftables/index.php/Configuring_chains.

Variants



Ingress

Ingress allows traffic-filtering before pre-routing, after the packet traversed the NIC.

Only available for the netdev-family.



Prerouting

Prerouting allows traffic-filtering before the packets have been routed.



Input

Input allows traffic-filtering for packets that have been routed to the local system.



Forward

Forward allows traffic-filtering for packets that were not routed to the local system.



Output

Output allows traffic-filtering for packets leaving the local system.



Postrouting

Postrouting allows traffic-filtering for already routed packets leaving the local system.