pub enum RuleVerdict {
Accept,
Drop,
Reject,
}Expand description
Representation of rule policies.
Attribution
Parts of the documentation have been taken from https://wiki.nftables.org/wiki-nftables/index.php/Configuring_chains.
Variants
Accept
The accept verdict means that the packet will keep traversing the network stack.
Drop
The drop verdict means that the packet is discarded if the packet reaches the end of the base chain.
Reject
The reject verdict means that the packet is responded to with an ICMP message stating that it was rejected.