pub struct ContainerToWiderWorld {
pub default_policy: RuleVerdict,
pub rules: Option<Vec<ContainerToWiderWorldRule>>,
}Expand description
The container-to-wider-world section, defining how containers can communicate with the wider world.
Fields
default_policy: RuleVerdictThe default_policy defines the default for when there is not a specific rule.
rules: Option<Vec<ContainerToWiderWorldRule>>An optional list of rules, see
ContainerToWiderWorldRule.
Example
The easiest way to define the rules is using TOMLs arrays of tables:
[container_to_wider_world]
default_policy = "drop"
[[container_to_wider_world.rules]]
# first rule here
[[container_to_wider_world.rules]]
# second rule hereTrait Implementations
Sourceimpl Clone for ContainerToWiderWorld
impl Clone for ContainerToWiderWorld
Sourcefn clone(&self) -> ContainerToWiderWorld
fn clone(&self) -> ContainerToWiderWorld
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ContainerToWiderWorld
impl Debug for ContainerToWiderWorld
Sourceimpl<'de> Deserialize<'de> for ContainerToWiderWorld
impl<'de> Deserialize<'de> for ContainerToWiderWorld
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for ContainerToWiderWorld
impl Hash for ContainerToWiderWorld
Sourceimpl PartialEq for ContainerToWiderWorld
impl PartialEq for ContainerToWiderWorld
Sourceimpl Process<Iptables> for ContainerToWiderWorld
impl Process<Iptables> for ContainerToWiderWorld
Sourcefn process(
&self,
ctx: &ProcessContext<'_, Iptables>,
) -> Result<Option<Vec<IptablesRule>>>
fn process( &self, ctx: &ProcessContext<'_, Iptables>, ) -> Result<Option<Vec<IptablesRule>>>
Process the current type within the given
ProcessContext, returning zero or more rules
to apply with nft.Sourceimpl Process<Nftables> for ContainerToWiderWorld
impl Process<Nftables> for ContainerToWiderWorld
Sourcefn process(
&self,
ctx: &ProcessContext<'_, Nftables>,
) -> Result<Option<Vec<String>>>
fn process( &self, ctx: &ProcessContext<'_, Nftables>, ) -> Result<Option<Vec<String>>>
Process the current type within the given
ProcessContext, returning zero or more rules
to apply with nft.impl Eq for ContainerToWiderWorld
impl StructuralPartialEq for ContainerToWiderWorld