WiderWorldToContainer

Struct WiderWorldToContainer 

pub struct WiderWorldToContainer {
    pub rules: Option<Vec<WiderWorldToContainerRule>>,
}
The wider-world-to-container section, defining how containers can reached from the wider world.

Fields

rules: Option<Vec<WiderWorldToContainerRule>>

An optional list of rules, see WiderWorldToContainerRule.

Example

The easiest way to define the rules is using TOMLs arrays of tables:

[[wider_world_to_container.rules]]
# first rule here
[[wider_world_to_container.rules]]
# second rule here