pub struct WiderWorldToContainer {
pub rules: Option<Vec<WiderWorldToContainerRule>>,
}Expand description
The wider-world-to-container section, defining how containers can reached from the wider world.
Fields
rules: Option<Vec<WiderWorldToContainerRule>>An optional list of rules, see
WiderWorldToContainerRule.
Example
The easiest way to define the rules is using TOMLs arrays of tables:
[[wider_world_to_container.rules]]
# first rule here
[[wider_world_to_container.rules]]
# second rule hereTrait Implementations
Sourceimpl Clone for WiderWorldToContainer
impl Clone for WiderWorldToContainer
Sourcefn clone(&self) -> WiderWorldToContainer
fn clone(&self) -> WiderWorldToContainer
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WiderWorldToContainer
impl Debug for WiderWorldToContainer
Sourceimpl<'de> Deserialize<'de> for WiderWorldToContainer
impl<'de> Deserialize<'de> for WiderWorldToContainer
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for WiderWorldToContainer
impl Hash for WiderWorldToContainer
Sourceimpl PartialEq for WiderWorldToContainer
impl PartialEq for WiderWorldToContainer
Sourceimpl Process<Iptables> for WiderWorldToContainer
impl Process<Iptables> for WiderWorldToContainer
Sourcefn process(
&self,
ctx: &ProcessContext<'_, Iptables>,
) -> Result<Option<Vec<IptablesRule>>>
fn process( &self, ctx: &ProcessContext<'_, Iptables>, ) -> Result<Option<Vec<IptablesRule>>>
Process the current type within the given
ProcessContext, returning zero or more rules
to apply with nft.Sourceimpl Process<Nftables> for WiderWorldToContainer
impl Process<Nftables> for WiderWorldToContainer
Sourcefn process(
&self,
ctx: &ProcessContext<'_, Nftables>,
) -> Result<Option<Vec<String>>>
fn process( &self, ctx: &ProcessContext<'_, Nftables>, ) -> Result<Option<Vec<String>>>
Process the current type within the given
ProcessContext, returning zero or more rules
to apply with nft.impl Eq for WiderWorldToContainer
impl StructuralPartialEq for WiderWorldToContainer